#include <avr/io.h>
#include <avr/signal.h>
#include <avr/interrupt.h>
#include <avr/delay.h>

#include "calibrateosc.h"

volatile static unsigned int actual_count;
    
void CalOsc(void)
    {
    unsigned char sreg_backup;
    unsigned int target_count;
    
    //Save the SREG
    sreg_backup = SREG;
    
    //Enable int 1 on rising edge
    EIMSK |= 1<<INT1;
    EICRA |= 1<<ISC11 | 1<<ISC10;
    
    //Enable interrupts
    sei();
    
    //Enable timer from system clock
    TCNT1 = 0;
    TCCR1B = 0x01;
    
    //What we want as the counter value
    //This should be done at compile time
    //target_count = target / reference - 10;
    target_count = 1805;
    
    while(1==1)
        {
        //Let it take a few readings
        _delay_loop_2(6000);
        
        //Clock is running too fast
        if (actual_count > (target_count + 5))
            {
            //Bit 7 selects low or high range
            //We only need low
            OSCCAL = (OSCCAL - 1) & ~(1<<7);
            }
        //Clock is running too slow
        else if (actual_count < (target_count - 5))
            {
            //Bit 7 selects low or high range
            //We only need low
            OSCCAL = (OSCCAL + 1) & ~(1<<7);
            }
       //Clock is just right
       else
            {
            break;
            }        
        }
    
    //OSCCAL = 0x00;
        
    EIMSK &= ~(1<<INT1);
        
    TCCR1B = 0x00;
    SREG = sreg_backup;
        
    return;
    }   


SIGNAL(SIG_INTERRUPT1)        
    {
    //Stop
    TCCR1B = 0x00;    
    
    //Record
    actual_count = TCNT1;
    
    //Go!
    TCNT1 = 0;
    TCCR1B = 0x01;
    }

