/********************************************************************
* PROJECT: LoonBoard Project
*
* COYRIGHT: Colin O'Flynn of NewAE, (C) 2005 <coflynn@newae.com>
*
* LICENSE: This file is released under a license specified in the LICENSE
*          file in the main project directory that this file was in. If
*          the license file is missing, then this file is NOT licensed
*          and all standard copyright laws apply. 
*
* FILE NAME: lub.h 
* 
* PURPOSE: Provides a number of routines to use the LoonBoard Unified
*          Bootloader (LUB) protocol to transmit and receive packets.
* 
* GLOBAL VARIABLES: 
* 
* Variable Type Description 
* -------- ---- ----------- 
* none
*
* DEVELOPMENT HISTORY: 
* 
* Date(DMY)   Author          Release   Description Of Change 
* ----        ------          -------   --------------------- 
* 30-04-2005  Colin O'Flynn   Initial   Initial file written
*
*******************************************************************/

#ifndef __LUB_HEADER
#define __LUB_HEADER

int lub_GetPacketStream(void (*char_process)(unsigned char, unsigned int), void (*verify_data)(void), unsigned char maxtries);
int lub_GetPacket(char * data, int maxsize, unsigned char maxtries);
int lub_SendPacket(unsigned char packettype, unsigned char * data, unsigned char maxtries);

int lub_EnterLUB(unsigned char which_lub);

#define LUB_SYNC        0xA9

#define LUB_SIGN_ON     0x00
#define LUB_ACK         0x01
#define LUB_NACK        0x02
#define LUB_SOT         0x03
#define LUB_EOT         0x04

#define LUB_SEND_FPGA   0xA0
#define LUB_SEND_AVR    0xA1
#define LUB_SEND_BOOT   0xA2
#define LUB_SEND_SAFEBOOT   0xA3

#define LUB_CRC1        0xAE

#define LUB_264_DATA    0xB0

#define LUB_SUICIDE     0xC0

#endif //__LUB_HEADER



