/********************************************************************
* PROJECT: LoonBoard Project
*
* COYRIGHT: Colin O'Flynn of NewAE, (C) 2005 <coflynn@newae.com>
*
* LICENSE: This file is released under a license specified in the LICENSE
*          file in the main project directory that this file was in. If
*          the license file is missing, then this file is NOT licensed
*          and all standard copyright laws apply. 
*
* FILE NAME: uart.c                                        
* 
* PURPOSE: Main file for the Loonboard Unified Bootloader (LUB) that runs
*          on the AVR target
* 
* FILE REFERENCES: 
* 
* Name                I/O   Description 
* ----                ---   ----------- 
* none
*
* ABNORMAL TERMINATION CONDITIONS, ERROR AND WARNING MESSAGES: 
* 
* ASSUMPTIONS, CONSTRAINTS, RESTRICTIONS: 
*   Doesn't really check for errors in serial communications
* 
* NOTES: 
* 
* REQUIREMENTS/FUNCTIONAL SPECIFICATIONS REFERENCES: 
* 
* DEVELOPMENT HISTORY: 
* 
* Date(DMY)   Author          Release   Description Of Change 
* ----        ------          -------   --------------------- 
* 1-05-2005  Colin O'Flynn    0.1      First working release
*
*******************************************************************/

#include <avr/io.h>
#include <avr/pgmspace.h>
#include "uart.h"

void uart_putc(char c)
    {
    loop_until_bit_is_set(UCSR0A, UDRE0);
    UDR0 = c;
    }
    
char uart_getc(void)
    {
    loop_until_bit_is_set(UCSR0A, RXC0);
    return UDR0;
    }
    
void uart_getcs(char *s, unsigned int counter)
    {
    while(counter != 0)
        {
        *s = uart_getc();
        s++;
        counter--;
        }
    return;
    }
    
void uart_putcs(char *s, unsigned int counter)
    {
    while(counter != 0)
        {
        uart_putc(*s);
        s++;
        counter--;
        }
    return;
    }
    

void uart_puts(char *s)
    {
    do
    {
    uart_putc(*s);
    s++;    
    }while(*s != '\0');
    
    return;
    
    }
    
void uart_puts_P(const char *addr)
    {
    char c;
    
    do
    {
    c = pgm_read_byte(addr);
    uart_putc(c);
    addr++;    
    }while(c != '\0');
    
    }
