/********************************************************************
* PROJECT: LoonBoard Project
*
* COYRIGHT: Colin O'Flynn of NewAE, (C) 2005 <coflynn@newae.com>
*
* LICENSE: This file is released under a license specified in the LICENSE
*          file in the main project directory that this file was in. If
*          the license file is missing, then this file is NOT licensed
*          and all standard copyright laws apply. 
*
* FILE NAME: x1226.c                                     
* 
* PURPOSE: Communications for X1226
* 
* FILE REFERENCES: 
* 
* Name                I/O   Description 
* ----                ---   ----------- 
* twi_comms.c         IO    Two Wire Interface
*
*
* ABNORMAL TERMINATION CONDITIONS, ERROR AND WARNING MESSAGES: 
* 
* ASSUMPTIONS, CONSTRAINTS, RESTRICTIONS: 
* 
* NOTES: 
* 
* REQUIREMENTS/FUNCTIONAL SPECIFICATIONS REFERENCES: 
* 
* DEVELOPMENT HISTORY: 
* 
* Date(DMY)   Author          Release   Description Of Change 
* ----        ------          -------   --------------------- 
* 15-02-2005  Colin O'Flynn    0.1      First working release
*
*******************************************************************/

#include <avr/io.h>

#include "x1226.h"
#include "twi_comms.h"
#include "error.h"

ERROR_T x1226_init(void)
	{
	unsigned char buffer[1];
	buffer[0] = 0x02;
	
	//Enable write access to chip
	return (x1226_random_write(X1226_CCR, 0x3F, buffer, 1));
	}

ERROR_T x1226_random_read(enum x1226_sla_t x1226_sla, uint16_t address, uint8_t *data, unsigned char numbytes)
    {
	uint8_t adddata[2];
    ERROR_T error;
	
	adddata[1] = (uint8_t) address;
	adddata[0] = (uint8_t) ((uint16_t)address >> 8);
    
    error = twi_send(x1226_sla, adddata, 2);
    
    if (error != ERROR_NONE)
        {
        return error;
        }
        
    error = twi_get(x1226_sla, data, numbytes);
    
    if (error != ERROR_NONE)
        {
        return error;
        }
    
    twi_stop();
    
    return ERROR_NONE;
    }
	
ERROR_T x1226_random_write(enum x1226_sla_t x1226_sla, uint16_t address, uint8_t *data, unsigned char numbytes)
	{
	uint8_t adddata[2];
    ERROR_T error;
    unsigned char maxtries;
	
	adddata[1] = (uint8_t) address;
	adddata[0] = (uint8_t) ((uint16_t)address >> 8);
    
    /* The device returns NACK to the address if it is busy, so try a bunch of times */
    maxtries = 0;
    do
        {
        error = twi_send(x1226_sla, adddata, 2);
        maxtries++;
        }while ((error != ERROR_NONE) && (maxtries < 30));
        
    if (maxtries == 30)
        return error;

	error = twi_send_data(data, numbytes);
	    if (error != ERROR_NONE)
        {
        return error;
        }
	twi_stop();
	
	return ERROR_NONE;
	}
	
ERROR_T x1226_testee(void)
	{
	uint16_t address;
	uint8_t	 data[1];
	ERROR_T error;
	
	address = 0x0000;
	
	while (address < 0x01FF)
		{
		data[0] = (uint8_t)address ^ 0xAA;		
		error =x1226_random_write(X1226_EE, address, data, 1);
        //printf("Address %x wrote %x\n", address, data[0]);
		if (error != ERROR_NONE)
			return error;
		address++;
		}
		
	address = 0x0000;
	while (address < 0x01FF)
		{
		error =x1226_random_read(X1226_EE, address, data, 1);
        //printf("Address %x read %x\n", address, data[0]);
		if (error != ERROR_NONE)
			return error;
		if (data[0] != ((uint8_t)address ^ 0xAA))
            return ERROR_TEST_FAILED;
		address++;
        }
        
    return ERROR_NONE;
    }
